@@ -21,7 +21,7 @@ class GestPAY(object):
 
         return data
 
-    def card_transaction(self, amount, transaction_id, card_number, exp_month, exp_year, currency=GPAY_DEFAULT_CURRENCY, **kwargs):
+    def card_transaction(self, amount, transaction_id, card_number, exp_month, exp_year, currency=GPAY_DEFAULT_CURRENCY, buyer_name=None, buyer_email=None):
         data = self._prepare_request()
         data['amount'] = amount
         data['shopTransactionId'] = transaction_id
@@ -30,20 +30,25 @@ class GestPAY(object):
         data['expiryYear'] = exp_year
         data['uicCode'] = currency
 
-        for key, value in iteritems(kwargs):
-            data[key] = value
+        if buyer_name:
+            data['buyerName'] = buyer_name
+        if buyer_email:
+            data['buyerEmail'] = buyer_email
 
         return self.make_request('callPagamS2S', data)
 
-    def token_transaction(self, amount, transaction_id, token, currency=GPAY_DEFAULT_CURRENCY, **kwargs):
+    def token_transaction(self, amount, transaction_id, token, currency=GPAY_DEFAULT_CURRENCY, buyer_name=None, buyer_email=None):
         data = self._prepare_request()
         data['amount'] = amount
         data['shopTransactionId'] = transaction_id
         data['tokenValue'] = token
+        data['uicCode'] = currency
+
+        if buyer_name:
+            data['buyerName'] = buyer_name
+        if buyer_email:
+            data['buyerEmail'] = buyer_email
 
-        for key, value in itervalues(kwargs):
-            data[key] = value
-    
         return self.make_request('callPagamS2S', data)
 
     def read_transaction(self, transaction_id, bank_transaction_id=False):
@@ -69,7 +74,7 @@ class GestPAY(object):
         data['bankTransactionId'] = bank_transaction_id
         data['uicCode'] = currency
 
-        for key, value in iteritems(kwargs):
+        for key, value in itervalues(kwargs):
             data[key] = value
 
         return self.make_request('CallRefundS2S', data)
